# Gopad: SDK for Python

[![General Workflow](https://github.com/gopad/gopad-python/actions/workflows/general.yml/badge.svg)](https://github.com/gopad/gopad-python/actions/workflows/general.yml) [![Join the Matrix chat at https://matrix.to/#/#gopad:matrix.org](https://img.shields.io/badge/matrix-%23gopad%3Amatrix.org-7bc9a4.svg)](https://matrix.to/#/#gopad:matrix.org) [![Codacy Badge](https://app.codacy.com/project/badge/Grade/0581d0652d4d4dddb3fc353f74cd9bed)](https://app.codacy.com/gh/gopad/gopad-python/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade) [![PyPI Version](https://badge.fury.io/py/gopad.svg)](https://badge.fury.io/py/gopad)

This repository provides a client SDK for Python. This SDK is automatically
generated by the [OpenAPI Generator][generator] project:

-   API version: 1.0.0-alpha1
-   Package version: 1.5.1
-   Build package: org.openapitools.codegen.languages.PythonClientCodegen

For more information, please visit [https://gopad.eu](https://gopad.eu)

## Requirements

Python 3.7+

## Installation

If you want to use one of the versions released via PyPi you just need to
execute the following command within your project directory, after that you can
import it as other libraries:

```console
pip install gopad@1.5.1
```

## Tests

```console
pytest
```

## Security

If you find a security issue please contact
[gopad@webhippie.de](mailto:gopad@webhippie.de) first.

## Contributing

Fork -> Patch -> Push -> Pull Request

## Authors

-   [Thomas Boerger](https://github.com/tboerger)

## License

Apache-2.0

## Copyright

```console
Copyright (c) 2018 Thomas Boerger <thomas@webhippie.de>
```

[generator]: https://openapi-generator.tech
[setuptools]: http://pypi.python.org/pypi/setuptools
